pub struct GlobalAppStateDir { /* private fields */ }Expand description
Representation of a directory below $HOME in which to keep state for the installation. The full folder structure of that folder should be represented via this type. Method calls to particular subfolders create subfolder(s) as necessary.
Implementations
Sourceimpl GlobalAppStateDir
impl GlobalAppStateDir
Sourcepub fn new() -> Result<Self, Error>
pub fn new() -> Result<Self, Error>
Retrieves the $HOME value and creates the main subdir if necessary.
pub fn subdir(&self, dir_name: &str) -> Result<PathBuf>
pub fn run_queues_basedir(&self) -> Result<PathBuf>
Sourcepub fn run_queue_signal_change_path(&self) -> PathBuf
pub fn run_queue_signal_change_path(&self) -> PathBuf
Signals written to this file indicate the need to (e.g., currently) regenerate the top-level HTML files for the output directory
Sourcepub fn run_queue_change_done_path(&self) -> PathBuf
pub fn run_queue_change_done_path(&self) -> PathBuf
Record of reactions to signals on “.queues_change.signals”
Sourcepub fn working_directory_pool_base(&self) -> Result<PathBuf>
pub fn working_directory_pool_base(&self) -> Result<PathBuf>
The pool of project clones which are used for building and benchmarking
Sourcepub fn working_directory_for_polling_pool_base(&self) -> Result<PathBuf>
pub fn working_directory_for_polling_pool_base(&self) -> Result<PathBuf>
The pool of project clones (only 1, but the pool infrastructure is used to handle errors) for polling and for verifying commit ids on insertion
Sourcepub fn already_inserted_base(&self) -> Result<PathBuf>
pub fn already_inserted_base(&self) -> Result<PathBuf>
A KeyVal database of (run_parameters -> insertion time), for jobs already requested.